#
# spec file for package libtorrent
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define soname 14

Name:           libtorrent
Version:        0.13.2
Release:        1.2
Summary:        BitTorrent Library
License:        GPL-2.0
Group:          System/Libraries
Url:            http://libtorrent.rakshasa.no/
Source:         http://libtorrent.rakshasa.no/downloads/%{name}-%{version}.tar.gz
Source99:       libtorrent-rpmlintrc
Patch1:         libtorrent-add_missing_lphtread.patch
%if 0%{?suse_version} >= 1030
BuildRequires:  libopenssl-devel
%else
BuildRequires:  openssl-devel
%endif
BuildRequires:  gcc-c++
BuildRequires:  libsigc++2-devel
BuildRequires:  libstdc++-devel
%if 0%{?suse_version} > 1020
BuildRequires:  libcppunit-devel
%else
BuildRequires:  cppunit-devel
%endif
BuildRequires:  glibc-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRoot:	%{_tmppath}/%{name}-%{version}-build

%description
LibTorrent is a BitTorrent library written in C++ for *nix, with a focus on
high performance and good code. The library differentiates itself from other
implementations by transfering directly from file pages to the network stack.
On high-bandwidth connections it is able to seed at 3 times the speed of the
official client.

%package -n libtorrent%{soname}
Summary:        BitTorrent Library
Group:          System/Libraries

%description -n libtorrent%{soname}
LibTorrent is a BitTorrent library written in C++ for *nix, with a focus on
high performance and good code. The library differentiates itself from other
implementations by transfering directly from file pages to the network stack.
On high-bandwidth connections it is able to seed at 3 times the speed of the
official client.

%package -n libtorrent-devel
Summary:        Development Environment for %{name}
Group:          Development/Libraries/C and C++
Requires:       libtorrent%{soname} = %{version}
%if 0%{?suse_version} >= 1030
Requires:       libopenssl-devel
%else
Requires:       openssl-devel
%endif
Requires:       libsigc++2-devel
Requires:       libstdc++-devel
Provides:       libtorrent%{soname}-devel = %{version}

%description -n libtorrent-devel
LibTorrent is a BitTorrent library written in C++ for *nix, with a focus on
high performance and good code. The library differentiates itself from other
implementations by transfering directly from file pages to the network stack.
On high-bandwidth connections it is able to seed at 3 times the speed of the
official client.

This package holds the development files for libtorrent.

%prep
%if 0%{?rev}
%setup -q -n "libtorrent"
%else
%setup -q -n "libtorrent-%{version}"
%endif
%patch1

%build
export CPPFLAGS="%{optflags} -fno-strict-aliasing"

[ -e ./configure ] || NOCONFIGURE=1 ./autogen.sh
%configure \
    --enable-ipv6 \
    --with-epoll

%if 0%{?suse_version} >= 1120 && "%{_lib}" == "lib64" || 0%{?suse_version} > 1120
cat<<EOF >>config.h
#define HAVE_FALLOCATE 1
#if defined(USE_POSIX_FALLOCATE)
#undef USE_POSIX_FALLOCATE
#endif
EOF
%else
cat<<EOF >>config.h
#define USE_POSIX_FALLOCATE 1
#if defined(HAVE_FALLOCATE)
#undef HAVE_FALLOCATE
#endif
EOF
%endif

make %{?_smp_mflags}

%install
%make_install

rm "%{buildroot}%{_libdir}"/*.la

%post   -n libtorrent%{soname} -p /sbin/ldconfig
%postun -n libtorrent%{soname} -p /sbin/ldconfig

%files -n libtorrent%{soname}
%defattr(-,root,root)
%doc AUTHORS COPYING README
%{_libdir}/libtorrent.so.%{soname}
%{_libdir}/libtorrent.so.%{soname}.*.*

%files -n libtorrent-devel
%defattr(-,root,root)
%{_includedir}/torrent
%{_libdir}/libtorrent.so
%{_libdir}/pkgconfig/libtorrent.pc

%changelog
* Fri Apr 11 2014 i@margueirte.su
- update version 0.13.2
* Tue Nov 22 2011 pascal.bleser@opensuse.org
- update to 0.12.9
* Mon May  3 2010 pascal@links2linux.de
- update to SVN revision 1169:
  * redirects can now be made efficiently using rpc::CommandMap::create_redirect or "methods.redirect=new_key,dest_key"
  * added a missing READ_PORT case to a switch in handshake.cc
* Sat Mar 27 2010 pascal@links2linux.de
- update to SVN revision 1154
* Thu Mar 18 2010 pascal@links2linux.de
- add missing -lpthread in libtorrent.pc to fix build on <= 11.0
* Thu Mar 18 2010 pascal@links2linux.de
- don't use fallocate64 on 11.2 32bit, as it's not properly exported
  in glibc 2.10, use posix_fallocate instead
* Wed Mar 17 2010 pascal@links2linux.de
- update to SVN revision 1148 (0.12.6):
  * upstream magnet URI support, dropped patches
  * SONAME bumped from 11 to 13
* Fri Dec 11 2009 pascal.bleser@opensuse.org
- update to SVN revision 1110 (pre 0.12.6)
- add magnet URI support patches
* Tue Sep 29 2009 pascal.bleser@opensuse.org
- update to 0.12.5
* Mon Sep 28 2009 pascal.bleser@opensuse.org
- enable XMLRPC support
- minor spec file rewrite to use a %%%%soname macro
- pass -fno-strict-aliasing to build
- fix build on Factory
- remove .la file from -devel package
* Mon Nov 24 2008 guru@unixtech.be
- update to 0.12.4
* Tue Nov 11 2008 guru@unixtech.be
- dropped GCC 4.3 patch, merged upstream
- bumped SONAME to 11
- update to 0.12.3
* Mon Jul 21 2008 guru@unixtech.be
- moved to Packman repository
- new upstream version, revived
* Sun Apr  9 2006 guru@unixtech.be
- new upstream version
* Tue Feb 21 2006 guru@unixtech.be
- new upstream version
* Thu Sep  8 2005 guru@unixtech.be
- version 0.7.0-1
* Sat Apr 23 2005 guru@unixtech.be
- version 0.6.0
* Sat Mar 19 2005 guru@unixtech.be
- version 0.5.4
* Thu Mar  3 2005 guru@unixtech.be
- new package
